/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2010 EBM WebSourcing - http://www.petalslink.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.se.talend.processor;

import java.util.logging.Level;
import org.ow2.petals.component.framework.api.message.Exchange;
import org.ow2.petals.se.talend.TalendSe;
import org.ow2.petals.se.talend.model.TalendBusinessException;
import org.ow2.petals.se.talend.model.TalendTechnicalException;

/**
 * The exchange processor for InOnly MEP.
 * <p>
 * The only difference with the RobustInOnly processor is that we do not set any
 * output, including faults.
 * </p>
 * 
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class InOnlyProcessor extends RobustInOnlyProcessor {

    /**
     * Constructor.
     * @param talendSe
     */
    public InOnlyProcessor( TalendSe talendSe ) {
        super( talendSe );
    }


    /**
     * Processes an exchange for the Talend SE, according to the InOnly MEP.
     * <p>
     * This method sets nothing on the exchange.
     * </p>
     * 
     * @see org.ow2.petals.se.talend.processor.AbstractExchangeProcessor
     * #onJbiMessage(java.lang.String, org.ow2.petals.component.framework.api.message.Exchange)
     * 
     * TODO: The response should be sent before the job processing rather than after.
     */
    @Override
    public boolean onJbiMessage( String logHint, Exchange exchange ) {

        this.logHint = logHint;
        try {
            validateAndRun( exchange );

        } catch( TalendTechnicalException e ) {
            if( this.log.isLoggable( Level.INFO ))
                this.log.info( logHint + " encountered a problem. " + e.getMessage());

        } catch( TalendBusinessException e ) {
            if( this.log.isLoggable( Level.INFO ))
                this.log.info( logHint + " encountered a problem. " + e.getMessage());
        }

        return true;
    }
}
