/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2010 EBM WebSourcing - http://www.petalslink.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.se.talend.utils;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import javax.activation.DataSource;

/**
 * A data source which contains a file content.
 * <p>
 * This class works like FileDataSource, but does not require
 * the file to still exist when getInputStream() is called.
 * </p>
 * 
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class FileContentDataSource implements DataSource {

    private final String name;
    private final byte[] fileCcontent;


    /**
     * Constructor.
     * @param file
     * @throws IOException
     */
    public FileContentDataSource( File file ) throws IOException {

        FileInputStream fis = new FileInputStream( file );
        int size = Long.valueOf( file.length()).intValue();
        ByteArrayOutputStream bos = new ByteArrayOutputStream( size );
        TalendUtils.copyStream( fis, bos );
        fis.close();
        bos.close();

        this.name = file.getName();
        this.fileCcontent = bos.toByteArray();
    }


    /* (non-Javadoc)
     * @see javax.activation.DataSource#getContentType()
     */
    public String getContentType() {
        return "application/octet-stream";
    }


    /* (non-Javadoc)
     * @see javax.activation.DataSource#getInputStream()
     */
    public InputStream getInputStream() throws IOException {
        return new ByteArrayInputStream( this.fileCcontent );
    }


    /* (non-Javadoc)
     * @see javax.activation.DataSource#getName()
     */
    public String getName() {
        return this.name;
    }


    /* (non-Javadoc)
     * @see javax.activation.DataSource#getOutputStream()
     */
    public OutputStream getOutputStream() throws IOException {

        OutputStream os = new ByteArrayOutputStream();
        TalendUtils.copyStream( getInputStream(), os );
        return os;
    }
}
