/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2010 EBM WebSourcing - http://www.petalslink.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

package org.ow2.petals.se.talend.utils;

import java.lang.reflect.Field;
import java.net.URL;
import java.net.URLClassLoader;
import java.util.Collection;
import java.util.jar.JarFile;

/**
 * An alternative to {@link URLClassLoader} with a close() method.
 * <p>
 * This class prevents jar files from being locked.
 * See http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=5041014.
 * </p>
 * 
 * FIXME: this class should be moved in the CDK.
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class TalendURLClassLoader extends URLClassLoader {

	/**
	 * Constructor.
	 * @param urls
	 */
	public TalendURLClassLoader( URL[] urls ) {
		super( urls );
	}


	/**
	 * Constructor.
	 * @param urls
	 * @param parent
	 */
	public TalendURLClassLoader( URL[] urls, ClassLoader parent ) {
		super( urls, parent );
	}


	/**
	 * Closes the class loader, by freeing all its resources (in particular, closes all the JAR files).
	 * <p>
	 * I am not the author of this method.
	 * See http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=5041014
	 * Thanks to the real author. ;)
	 * </p>
	 */
	public void close() {

		try {
			Class<?> clazz = URLClassLoader.class;
			Field ucp = clazz.getDeclaredField( "ucp" );
			ucp.setAccessible( true );
			Object sun_misc_URLClassPath = ucp.get( this );
			Field loaders = sun_misc_URLClassPath.getClass().getDeclaredField( "loaders" );

			loaders.setAccessible( true );
			Object java_util_Collection = loaders.get( sun_misc_URLClassPath );
			for( Object sun_misc_URLClassPath_JarLoader : ((Collection<?>) java_util_Collection).toArray()) {

				try {
					Field loader = sun_misc_URLClassPath_JarLoader.getClass().getDeclaredField( "jar" );
					loader.setAccessible( true );
					Object java_util_jar_JarFile = loader.get( sun_misc_URLClassPath_JarLoader );
					((JarFile) java_util_jar_JarFile).close();

				} catch (Throwable t) {
					// if we got this far, this is probably not a JAR loader so skip it
				}
			}

		} catch( Throwable t ) {
			// probably not a SUN VM
		}

		return;
	}
}
